@@ -1,9 +1,11 @@
+#include <stdio.h>
 /* ========================================================================
 ** Extended Template and Library
 ** Angle Abstraction Class Implementation
-** $Id: _angle.h 334 2007-03-16 00:37:48Z dooglus $
+** $Id: _angle.h 848 2007-10-06 02:25:36Z dooglus $
 **
 ** Copyright (c) 2002 Robert B. Quattlebaum Jr.
+** Copyright (c) 2007 Chris Moore
 **
 ** This package is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License as
@@ -39,6 +41,8 @@
 # define HALF_PI (PI/2)
 #endif
 
+#define ANGLE_EPSILON (1.0e-6)
+
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
@@ -59,7 +63,7 @@ public:
 protected:
 	typedef value_type unit;
 
-	unit v;	//! Stored in rotations
+	unit v;	//! Stored in radians; positive values indicate counter-clockwise.
 
 public:
 
@@ -69,41 +73,41 @@ public:
 
 	const angle	&
 	operator+=(const angle &rhs)
-		{ v+=rhs.v; return *this; }
+	{ v+=rhs.v; return *this; }
 
 	const angle	&
 	operator-=(const angle &rhs)
-		{ v-=rhs.v; return *this; }
+	{ v-=rhs.v; return *this; }
 
 	const angle	&
 	operator*=(const unit &rhs)
-		{ v*=rhs; return *this; }
+	{ v*=rhs; return *this; }
 
 	const angle	&
 	operator/=(const unit &rhs)
-		{ v/=rhs; return *this; }
+	{ v/=rhs; return *this; }
 
 	//! Angle Addition Operator
 	angle
 	operator+(const angle &rhs)const
-		{ return angle(*this)+=rhs; }
+	{ return angle(*this)+=rhs; }
 
 	//! Angle Subtraction Operator
 	/*! \sa angle dist(const angle &) */
 	angle
 	operator-(const angle &rhs)const
-		{ return angle(*this)-=rhs; }
+	{ return angle(*this)-=rhs; }
 
 	//! Angle Scalar Multiplication Operator
 	/*! This operator will multiply the given
 		angle by the given scalar value. */
 	angle
 	operator*(const unit &rhs)const
-		{ return angle(*this)*=rhs; }
+	{ return angle(*this)*=rhs; }
 
 	angle
 	operator/(const unit &rhs)const
-		{ return angle(*this)/=rhs; }
+	{ return angle(*this)/=rhs; }
 
 	//! Angle Negation
 	angle
@@ -122,61 +126,66 @@ public:
 	operator~()const
 	{
 		angle ret;
-		ret.v=(value_type)std::floor(v+0.5f);
-		return ret;
+		ret.v = v+PI;
+		return ret.mod();
 	}
 
 	/*! Returns true if the shortest
-		angle between the left-hand and
-		right-hand side is clockwise */
-	bool
-	operator<(const angle &rhs)const
-	{ return v<rhs.v; }
-//	{ return dist(rhs).v<(value_type)0.0; }
-
-	/*! Returns true if the shortest
-		angle between the left-hand and
+		angle from the left-hand to the
 		right-hand side is counter-clockwise */
 	bool
-	operator>(const angle &rhs)const
-	{ return v>rhs.v; }
-//	{ return dist(rhs).v>(value_type)0.0; }
+	operator<(const angle &rhs)const
+	{ return dist(rhs).v<(value_type)0.0; }
 
 	/*! Returns true if the shortest
-		angle between the left-hand and
-		right-hand side is clockwise,
-		or if the angles are refer to the same
-		point on the unit circle. */
+		angle from the left-hand to the
+		right-hand side is clockwise */
 	bool
-	operator<=(const angle &rhs)const
-	{ return v<=rhs.v; }
-//	{ return dist(rhs).v<=(value_type)0.0; }
+	operator>(const angle &rhs)const
+	{ return dist(rhs).v>(value_type)0.0; }
 
 	/*! Returns true if the shortest
-		angle between the left-hand and
+		angle from the left-hand to the
 		right-hand side is counter-clockwise,
 		or if the angles are refer to the same
 		point on the unit circle. */
 	bool
+	operator<=(const angle &rhs)const
+	{ return dist(rhs).v<=(value_type)0.0; }
+
+	/*! Returns true if the shortest
+		angle from the left-hand to the
+		right-hand side is clockwise,
+		or if the angles are refer to the same
+		point on the unit circle. */
+	bool
 	operator>=(const angle &rhs)const
-	{ return v>=rhs.v; }
-//	{ return dist(rhs).v>=(value_type)0.0; }
+	{ return dist(rhs).v>=(value_type)0.0; }
 
 	/*! Returns true if the angles
 		are refer to the same point
 		on the unit circle. */
 	bool
 	operator==(const angle &rhs)const
-	{ return v==rhs.v; }
-//	{ return dist(rhs).v==(value_type)0.0; }
+	{ return std::abs(dist(rhs).v)<ANGLE_EPSILON; }
 
 	/*! Returns false if the angles
 		are refer to the same point
 		on the unit circle. */
 	bool
 	operator!=(const angle &rhs)const
-	{ return v!=rhs.v; }
-//	{ return dist(rhs).v!=(value_type)0.0; }
+	{ return std::abs(dist(rhs).v)>ANGLE_EPSILON; }
+
+	//! Absolute Angle Function
+	/*! This function will return the
+		absolute value of the angle. */
+	angle
+	abs()const
+	{
+		angle ret;
+		ret.v=std::abs(v);
+		return ret;
+	}
 
 	//! Angle Difference Function
 	/*! This function will return the
@@ -187,11 +196,8 @@ public:
 	dist(const angle &rhs)const
 	{
 		angle ret;
-
 		ret.v=v-rhs.v;
-
 		ret.v-=rot_floor(ret.v+PI);
-
 		return ret;
 	}
 
@@ -206,6 +212,7 @@ public:
 		return ret;
 	}
 
+	//! Zero Rotation (0 degrees)
 	static angle
 	zero()
 	{
@@ -214,23 +221,25 @@ public:
 		return ret;
 	}
 
+	//! One Complete Rotation (360 degrees)
 	static angle
 	one()
+	{
+		angle ret;
+		ret.v=PI*2;
+		return ret;
+	}
+
+	//! One Half Rotation (180 degrees)
+	static angle
+	half()
 	{
 		angle ret;
 		ret.v=PI;
 		return ret;
 	}
 
-	static angle
-	half()
-	{
-		angle ret;
-		ret.v=PI*0.5;
-		return ret;
-	}
-
-	bool operator!()const { return v==0; }
+	bool operator!()const { return std::abs(mod().v) < ANGLE_EPSILON; }
 
 private:
 
@@ -239,7 +248,7 @@ private:
 
 public:
 	/*
-	** Converstion Classes
+	** Conversion Classes
 	*/
 
 	class rad;
@@ -247,7 +256,7 @@ public:
 	class rot;
 
 	/*
-	** Trigometric Classes
+	** Trigonometric Classes
 	*/
 
 	class sin;
@@ -289,12 +298,12 @@ public:
 	rad(const angle &a):angle(a) { }
 	rad	mod()const { return angle::mod(); }
 	rad dist(const angle &rhs)const { return angle::dist(rhs); }
-#ifndef ETL_NO_DEPRECATED
-	operator value_type()const ETL_DEPRECATED_FUNCTION;
-#endif
 	value_type get()const { return v; }
+#ifndef ETL_NO_DEPRECATED
+	// operator value_type()const ETL_DEPRECATED_FUNCTION;
+#endif
 }; // END of class angle::radians
-inline angle::rad::operator angle::value_type()const { return get(); }
+// inline angle::rad::operator angle::value_type()const { return get(); }
 
 // ========================================================================
 /*!	\class	angle::deg	_angle.h	ETL/angle
@@ -311,10 +320,10 @@ public:
 	deg dist(const angle &rhs)const { return angle::dist(rhs); }
 	value_type get()const { return v*360/(PI*2); }
 #ifndef ETL_NO_DEPRECATED
-	operator value_type()const ETL_DEPRECATED_FUNCTION;
+	// operator value_type()const ETL_DEPRECATED_FUNCTION;
 #endif
 }; // END of class angle::degrees
-inline angle::deg::operator angle::value_type()const { return get(); }
+// inline angle::deg::operator angle::value_type()const { return get(); }
 
 // ========================================================================
 /*!	\class	angle::rot	_angle.h	ETL/angle
@@ -331,10 +340,10 @@ public:
 	rot dist(const angle &rhs)const { return angle::dist(rhs); }
 	value_type get()const { return v/(PI*2); }
 #ifndef ETL_NO_DEPRECATED
-	operator value_type()const ETL_DEPRECATED_FUNCTION;
+	// operator value_type()const ETL_DEPRECATED_FUNCTION;
 #endif
 }; // END of class angle::rotations
-inline angle::rot::operator angle::value_type()const { return get(); }
+// inline angle::rot::operator angle::value_type()const { return get(); }
 
 // ========================================================================
 /*!	\class	angle::sin	_angle.h	ETL/angle
@@ -351,10 +360,10 @@ public:
 	sin dist(const angle &rhs)const { return angle::dist(rhs); }
 	value_type get()const { return static_cast<value_type>(std::sin(v)); }
 #ifndef ETL_NO_DEPRECATED
-	operator value_type()const ETL_DEPRECATED_FUNCTION;
+	// operator value_type()const ETL_DEPRECATED_FUNCTION;
 #endif
 }; // END of class angle::sin
-inline angle::sin::operator angle::value_type()const { return get(); }
+// inline angle::sin::operator angle::value_type()const { return get(); }
 
 // ========================================================================
 /*!	\class	angle::cos	_angle.h	ETL/angle
@@ -369,12 +378,12 @@ public:
 	cos(const angle &a):angle(a) { }
 	cos	mod()const { return angle::mod(); }
 	cos dist(const angle &rhs)const { return angle::dist(rhs); }
-	operator value_type()const ETL_DEPRECATED_FUNCTION;
-#ifndef ETL_NO_DEPRECATED
 	value_type get()const { return (value_type)std::cos(v); }
+#ifndef ETL_NO_DEPRECATED
+	// operator value_type()const ETL_DEPRECATED_FUNCTION;
 #endif
 }; // END of class angle::cos
-inline angle::cos::operator angle::value_type()const { return get(); }
+// inline angle::cos::operator angle::value_type()const { return get(); }
 
 // ========================================================================
 /*!	\class	angle::tan	_angle.h	ETL/angle
@@ -390,12 +399,12 @@ public:
 	tan(const angle &a):angle(a) { }
 	tan	mod()const { return angle::mod(); }
 	tan dist(const angle &rhs)const { return angle::dist(rhs); }
-#ifndef ETL_NO_DEPRECATED
-	operator value_type()const ETL_DEPRECATED_FUNCTION;
-#endif
 	value_type get()const { return (value_type)std::tan(v); }
+#ifndef ETL_NO_DEPRECATED
+	// operator value_type()const ETL_DEPRECATED_FUNCTION;
+#endif
 }; // END of class angle::tan
-inline angle::tan::operator angle::value_type()const { return get(); }
+// inline angle::tan::operator angle::value_type()const { return get(); }
 
 _ETL_END_NAMESPACE
 
@@ -435,7 +444,6 @@ struct distance_func<etl::angle> : public std::binary_function<etl::angle, etl::
 	etl::angle uncook(const etl::angle &x)const { return x; }
 };
 
-
 /* === E N D =============================================================== */
 
 #endif
